@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2012-2018 Montel Laurent <montel@kde.org>
+  Copyright (c) 2012-2020 Laurent Montel <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by
@@ -190,10 +190,10 @@ void AutoCorrectionWidget::loadAutoCorrectionAndException()
     d->m_twoUpperLetterExceptions = d->mAutoCorrection->twoUpperLetterExceptions();
 
     d->ui->twoUpperLetterList->clear();
-    d->ui->twoUpperLetterList->addItems(d->m_twoUpperLetterExceptions.toList());
+    d->ui->twoUpperLetterList->addItems(d->m_twoUpperLetterExceptions.values());
 
     d->ui->abbreviationList->clear();
-    d->ui->abbreviationList->addItems(d->m_upperCaseExceptions.toList());
+    d->ui->abbreviationList->addItems(d->m_upperCaseExceptions.values());
 }
 
 void AutoCorrectionWidget::addAutoCorrectEntries()
@@ -589,10 +589,10 @@ void AutoCorrectionWidget::slotImportAutoCorrection(QAction *act)
                 d->m_twoUpperLetterExceptions = importAutoCorrection->twoUpperLetterExceptions();
 
                 d->ui->twoUpperLetterList->clear();
-                d->ui->twoUpperLetterList->addItems(d->m_twoUpperLetterExceptions.toList());
+                d->ui->twoUpperLetterList->addItems(d->m_twoUpperLetterExceptions.values());
 
                 d->ui->abbreviationList->clear();
-                d->ui->abbreviationList->addItems(d->m_upperCaseExceptions.toList());
+                d->ui->abbreviationList->addItems(d->m_upperCaseExceptions.values());
             }
             delete importAutoCorrection;
         }
