@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2016-2019 Montel Laurent <montel@kde.org>
+  Copyright (c) 2016-2020 Laurent Montel <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by
@@ -27,6 +27,10 @@
 class QTreeWidget;
 class QAction;
 namespace PimCommon {
+/**
+ * @brief The ConfigurePluginsListWidget class
+ * @author Laurent Montel <montel@kde.org>
+ */
 class PIMCOMMON_EXPORT ConfigurePluginsListWidget : public QWidget
 {
     Q_OBJECT
@@ -67,8 +71,7 @@ protected:
         bool mEnableFromUserSettings;
     };
     void savePlugins(const QString &groupName, const QString &prefixSettingKey, const QVector<PluginItem *> &listItems);
-    void fillTopItems(const QVector<PimCommon::PluginUtilData> &lst, const QString &topLevelItemName, const QString &groupName, const QString &prefixKey, QVector<PluginItem *> &itemsList,
-                      const QString &configureGroupName = QString(), bool checkable = true);
+    void fillTopItems(const QVector<PimCommon::PluginUtilData> &lst, const QString &topLevelItemName, const QString &groupName, const QString &prefixKey, QVector<PluginItem *> &itemsList, const QString &configureGroupName = QString(), bool checkable = true);
     void resetToUserSettings(const QVector<PluginItem *> &items);
     void changeState(const QVector<PluginItem *> &items);
 
