@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2013-2019 Montel Laurent <montel@kde.org>
+  Copyright (c) 2013-2020 Laurent Montel <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by
@@ -55,6 +55,9 @@ public:
         QListWidgetItem *item = new QListWidgetItem(name, q);
         item->setData(TemplateListWidget::Text, text);
         item->setData(TemplateListWidget::DefaultTemplate, isDefaultTemplate);
+        if (isDefaultTemplate) {
+            item->setIcon(QIcon::fromTheme(QStringLiteral("lock")));
+        }
         q->setCurrentItem(item);
     }
 
