@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2011-2018 Montel Laurent <montel@kde.org>
+ * Copyright (c) 2011-2020 Laurent Montel <montel@kde.org>
  *
  *  This program is free software; you can redistribute it and/or modify it
  *  under the terms of the GNU General Public License as published by
@@ -27,7 +27,7 @@
  *  your version.
  */
 #include "renamefiledialog.h"
-
+#include "kio_version.h"
 #include <kseparator.h>
 #include <QLineEdit>
 #include <QPushButton>
@@ -124,7 +124,7 @@ RenameFileDialog::RenameFileDialog(const QUrl &url, bool multiFiles, QWidget *pa
     : QDialog(parent)
     , d(new RenameFileDialogPrivate(url, this))
 {
-    setWindowTitle(i18n("File Already Exists"));
+    setWindowTitle(i18nc("@title:window", "File Already Exists"));
     QVBoxLayout *pLayout = new QVBoxLayout(this);
 
     QLabel *label = new QLabel(xi18n("A file named <filename>%1</filename> already exists. Do you want to overwrite it?", url.fileName()), this);
@@ -201,7 +201,11 @@ void RenameFileDialog::slotRenamePressed()
     if (newName().isLocalFile()) {
         fileExists = QFile::exists(newName().path());
     } else {
+#if KIO_VERSION < QT_VERSION_CHECK(5, 69, 0)
         auto job = KIO::stat(newName(), KIO::StatJob::DestinationSide, 0);
+#else
+        auto job = KIO::statDetails(newName(), KIO::StatJob::DestinationSide, KIO::StatDetail::Basic);
+#endif
         KJobWidgets::setWindow(job, this);
         fileExists = job->exec();
     }
