@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2013-2019 Montel Laurent <montel@kde.org>
+  Copyright (c) 2013-2020 Laurent Montel <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by
@@ -19,12 +19,8 @@
 #include "selectmulticollectionwidget.h"
 #include "folderdialog/checkedcollectionwidget.h"
 
-#include <RecursiveCollectionFilterProxyModel>
 #include <CollectionFilterProxyModel>
-
-#include <ChangeRecorder>
 #include <EntityTreeModel>
-#include <EntityRightsFilterModel>
 
 #include <KCheckableProxyModel>
 
