@@ -1,6 +1,6 @@
 /*
    Copyright 2010 Thomas McGuire <mcguire@kde.org>
-   Copyright 2014-2018 Laurent Montel <montel@kde.org>
+   Copyright 2014-2020 Laurent Montel <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
@@ -16,7 +16,7 @@
    GNU General Public License for more details.
 
    You should have received a copy of the GNU General Public License
-   along with this program.  If not, see <http://www.gnu.org/licenses/>.
+   along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */
 
 #include "annotationdialog.h"
@@ -30,7 +30,7 @@
 #include <item.h>
 #include <entityannotationsattribute.h>
 
-#include <KComboBox>
+#include <QComboBox>
 #include <QIcon>
 
 #include <QLabel>
@@ -50,7 +50,7 @@ public:
 
     Akonadi::Item mItem;
     KPIMTextEdit::PlainTextEditorWidget *mTextEdit = nullptr;
-    KComboBox *mNoteType = nullptr;
+    QComboBox *mNoteType = nullptr;
     bool mHasAnnotation = false;
 };
 
@@ -86,7 +86,7 @@ AnnotationEditDialog::AnnotationEditDialog(const Akonadi::Item &item, QWidget *p
 
     QLabel *label = new QLabel(i18n("Enter the text that should be stored as a note to the mail:"));
     QVBoxLayout *vbox = new QVBoxLayout(mainWidget);
-    vbox->setMargin(0);
+    vbox->setContentsMargins(0, 0, 0, 0);
     d->mTextEdit = new KPIMTextEdit::PlainTextEditorWidget(this);
     vbox->addWidget(label);
     vbox->addWidget(d->mTextEdit);
@@ -96,7 +96,7 @@ AnnotationEditDialog::AnnotationEditDialog(const Akonadi::Item &item, QWidget *p
     hbox->addStretch();
     label = new QLabel(i18nc("@label:listbox", "Note type:"));
     hbox->addWidget(label);
-    d->mNoteType = new KComboBox;
+    d->mNoteType = new QComboBox;
     hbox->addWidget(d->mNoteType);
     d->mNoteType->addItem(i18nc("@item:inlistbox", "Private note"), QByteArrayLiteral("/private/comment"));
     d->mNoteType->addItem(i18nc("@item:inlistbox", "Shared note"), QByteArrayLiteral("/shared/comment"));
